@@ -29,7 +29,7 @@
 
 #define FLOPPY BINDIR "/floppy"
 
-static const char rcsid[]="$Id: floppygtk.c,v 1.4 2003/04/22 00:03:11 mrsam Exp $";
+static const char rcsid[]="$Id: floppygtk.c,v 1.5 2003/08/14 15:31:14 mrsam Exp $";
 
 GtkWidget *window;	/* Main window */
 GtkWidget *window_vbox;	/* Vbox for menu bar, and dialog */
@@ -53,6 +53,8 @@ static char *drivename;
 */
 static void getsize(GtkWidget *w, const char *str, int *ww, int *h)
 {
+#if GTK_MAJOR_VERSION < 2
+
 	guint width;
 	guint lbearing;
 	guint rbearing;
@@ -73,6 +75,16 @@ static void getsize(GtkWidget *w, const char *str, int *ww, int *h)
 
 	*ww=width;
 	*h=ascent;
+#else
+
+	PangoLayout *layout;
+
+	layout = gtk_widget_create_pango_layout (w, "");
+	pango_layout_set_text (layout, str, -1);
+	pango_layout_get_pixel_size(layout, ww, h);
+	g_object_unref(layout);
+
+#endif
 }
 
 /*
